==> quanyi-center-api-1.3.60-contract-amount-20250701.100821-19-sources.jar: cn/com/duiba/quanyi/center/api/enums/workflow/WorkflowTypeEnum.java <==
package cn.com.duiba.quanyi.center.api.enums.workflow;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.Collections;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author lizhi
 * @date 2024/10/21 17:32
 */
@AllArgsConstructor
@Getter
public enum WorkflowTypeEnum {
    PROJECT(1, "项目审批", "创建审批流", "项目生效"),
    DEMAND(2, "需求审批", "创建审批流", "需求审批完成"),
    INVOICE_APPLY(3, "开票申请审批", "创建审批流", "开票审批完成"),
    INVOICE_RED_OFFSET(4, "红冲审批", "创建审批流", "红冲审批完成"),
    PAYMENT_APPLY(5, "付款申请记录审批", "创建审批流", "付款申请记录审批完成"),
    RECEIVED_PAYMENT_ASSOCIATION(6, "回款关联审批", "创建审批流", "回款关联审批审批完成"),
    RECEIVED_PAYMENT_DISASSOCIATION(7, "回款取消关联审批", "创建审批流", "回款取消关联审批审批完成"),
    CONTRACT(8, "合同审批", "创建审批流", "合同审批完成"),
    ACTIVITY_ENABLE(10, "活动启用审批", "创建审批流", "审批完成"),
    ;

    private final Integer type;

    private final String desc;

    /**
     * 发起人节点名称
     */
    private final String initActName;

    /**
     * 审批流结束后节点名称
     */
    private final String lastActName;

    private static final Map<Integer, WorkflowTypeEnum> ENUM_MAP = Collections.unmodifiableMap(Arrays.stream(values()).collect(Collectors.toMap(WorkflowTypeEnum::getType, Function.identity(), (v1, v2) -> v2)));

    /**
     * 根据枚举值获取枚举
     * @param type 枚举值
     * @return 枚举
     */
    public static WorkflowTypeEnum getByType(Integer type) {
        if (type == null) {
            return null;
        }
        return ENUM_MAP.get(type);
    }
}

==> quanyi-center-api-1.4.49-contract-amount-20251017.095318-2-sources.jar: cn/com/duiba/quanyi/center/api/enums/workflow/WorkflowTypeEnum.java <==
package cn.com.duiba.quanyi.center.api.enums.workflow;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.Collections;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author lizhi
 * @date 2024/10/21 17:32
 */
@AllArgsConstructor
@Getter
public enum WorkflowTypeEnum {
    PROJECT(1, "项目审批", "创建审批流", "项目生效"),
    DEMAND(2, "需求审批", "创建审批流", "需求审批完成"),
    INVOICE_APPLY(3, "开票申请审批", "创建审批流", "开票审批完成"),
    INVOICE_RED_OFFSET(4, "红冲审批", "创建审批流", "红冲审批完成"),
    PAYMENT_APPLY(5, "付款申请记录审批", "创建审批流", "付款申请记录审批完成"),
    RECEIVED_PAYMENT_ASSOCIATION(6, "回款关联审批", "创建审批流", "回款关联审批审批完成"),
    RECEIVED_PAYMENT_DISASSOCIATION(7, "回款取消关联审批", "创建审批流", "回款取消关联审批审批完成"),
    CONTRACT(8, "合同审批", "创建审批流", "合同审批完成"),
    DAYAN_CONTRACT(9, "数字营销合同审批", "创建审批流", "合同审批完成"),
    ACTIVITY_ENABLE(10, "活动启用审批", "创建审批流", "审批完成"),
    CREATE_DEMAND(11, "创建需求审批", "创建审批流", "审批完成"),
    ADD_DEMAND_GOODS(12, "新增需求商品审批", "创建审批流", "审批完成"),
    MODIFY_DEMAND_BUDGET_GOODS(13, "修改需求商品消耗预算审批(商品维度)", "创建审批流", "审批完成"),
    REFUND_APPROVAL(14, "支付订单退款审批", "创建审批流", "审批完成"),
    TOLERANCE_AMOUNT(15, "容差审批", "创建审批流", "审批完成"),
    PROJECT_LOSS(16, "项目资损审批", "创建审批流", "审批完成"),
    PREPAYMENT_REFUND(17, "预付款退款", "创建审批流", "审批完成"),
    MODIFY_DEMAND_BUDGET_DEMAND(24, "修改需求预算审批（需求维度）", "创建审批流", "审批完成"),
    ;

    private final Integer type;

    private final String desc;

    /**
     * 发起人节点名称
     */
    private final String initActName;

    /**
     * 审批流结束后节点名称
     */
    private final String lastActName;

    private static final Map<Integer, WorkflowTypeEnum> ENUM_MAP = Collections.unmodifiableMap(Arrays.stream(values()).collect(Collectors.toMap(WorkflowTypeEnum::getType, Function.identity(), (v1, v2) -> v2)));

    /**
     * 根据枚举值获取枚举
     * @param type 枚举值
     * @return 枚举
     */
    public static WorkflowTypeEnum getByType(Integer type) {
        if (type == null) {
            return null;
        }
        return ENUM_MAP.get(type);
    }
}
